@@ -5,7 +5,7 @@ use Moose;
 use Carp ();
 
 # ABSTRACT: Generate boilerplate documentation for Alien::Base subclass
-our $VERSION = '0.14'; # VERSION
+our $VERSION = '0.15'; # VERSION
 
 
 with 'Dist::Zilla::Role::FileMunger';
@@ -31,6 +31,13 @@ has class_name => (
 );
 
 
+has min_version => (
+  is      => 'ro',
+  isa     => 'Str',
+  default => '0',
+);
+
+
 has type => (
   is      => 'ro',
   isa     => 'ArrayRef[Str]',
@@ -92,8 +99,10 @@ sub render_synopsis
     
     $str .= "\n\n";
     $str .= $self->fill_in_string($template, {
-      class => $self->class_name,
-      name  => $self->name,
+      class      => $self->class_name,
+      name       => $self->name,
+      version    => $self->min_version,
+      optversion => $self->min_version ? " @{[ $self->min_version ]}" : '',
     });
   }
   
@@ -114,8 +123,10 @@ sub render_description
   my $str = "\n";
   
   $str .= $self->fill_in_string($template, {
-    class => $self->class_name,
-    name  => $self->name,
+    class      => $self->class_name,
+    name       => $self->name,
+    version    => $self->min_version,
+    optversion => $self->min_version ? " @{[ $self->min_version ]}" : '',
   });
   
   $str .= "\n\n";
@@ -196,7 +207,7 @@ Dist::Zilla::Plugin::AlienBase::Doc - Generate boilerplate documentation for Ali
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
@@ -237,6 +248,10 @@ least, better than nothing though!
 The name of the L<Alien::Base> subclass.  The default is based on the
 distribution's main module.
 
+=head2 min_version
+
+The minimum version to suggest using as a prereq.
+
 =head2 type
 
 Types of the L<Alien>.  This can be specified multiple times.  Valid types:
@@ -287,6 +302,10 @@ In your Build.PL:
  use {{ $class }};
  my $builder = Module::Build->new(
    ...
+   configure_requires => {
+     '{{ $class }}' => '{{ $version }}',
+     ...
+   },
    extra_compiler_flags => {{ $class }}->cflags,
    extra_linker_flags   => {{ $class }}->libs,
    ...
@@ -302,6 +321,9 @@ In your Makefile.PL:
  
  WriteMakefile(
    ...
+   CONFIGURE_REQUIRES => {
+     '{{ $class }}' => '{{ $version }}',
+   },
    CCFLAGS => {{ $class }}->cflags . " $Config{ccflags",
    LIBS    => [ {{ $class }}->libs ],
    ...
@@ -311,7 +333,7 @@ __[ __SYNOPSIS_FFI__ ]__
 In your L<FFI::Platypus> script or module:
 
  use FFI::Platypus;
- use {{ $class }};
+ use {{ $class }}{{ $optversion }};
  
  my $ffi = FFI::Platypus->new(
    lib => [ {{ $class }}->dynamic_libs ],
@@ -320,7 +342,7 @@ In your L<FFI::Platypus> script or module:
 __[ __SYNOPSIS_TOOL__ ]__
 In your script or module:
 
- use {{ $class }};
+ use {{ $class }}{{ $optversion }};
  use Env qw( @PATH );
  
  unshift @ENV, {{ $class }};
